<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AppLauncher</name>
    <message>
        <location filename="../src/tools/launcher/applaunchertool.cpp" line="34"/>
        <source>App Launcher</source>
        <translation>應用程式啟動器</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/applaunchertool.cpp" line="42"/>
        <source>Choose an app to open the capture</source>
        <translation>選擇一個程式打開此截圖</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="56"/>
        <source>Open With</source>
        <translation>打開</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="71"/>
        <source>Launch in terminal</source>
        <translation>在終端機中啟動</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="72"/>
        <source>Keep open after selection</source>
        <translation>選擇後維持此視窗開啟</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="99"/>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="111"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="112"/>
        <source>Unable to launch in terminal.</source>
        <translation>無法在終端機中啟動</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/applauncherwidget.cpp" line="99"/>
        <source>Unable to write in</source>
        <translation>無法寫入</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <location filename="../src/tools/arrow/arrowtool.cpp" line="80"/>
        <source>Arrow</source>
        <translation>箭頭</translation>
    </message>
    <message>
        <location filename="../src/tools/arrow/arrowtool.cpp" line="88"/>
        <source>Sets the Arrow as the paint tool</source>
        <translation>選擇箭頭作為繪製工具</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <location filename="../src/tools/blur/blurtool.cpp" line="34"/>
        <source>Blur</source>
        <translation>模糊</translation>
    </message>
    <message>
        <location filename="../src/tools/blur/blurtool.cpp" line="42"/>
        <source>Sets the Blur as the paint tool</source>
        <translation>選擇模糊作為繪製工具</translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <location filename="../src/widgets/capture/capturewidget.cpp" line="81"/>
        <source>Unable to capture screen</source>
        <translation>無法擷取螢幕</translation>
    </message>
    <message>
        <location filename="../src/widgets/capture/capturewidget.cpp" line="231"/>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <location filename="../src/tools/circle/circletool.cpp" line="34"/>
        <source>Circle</source>
        <translation>圈型</translation>
    </message>
    <message>
        <location filename="../src/tools/circle/circletool.cpp" line="42"/>
        <source>Sets the Circle as the paint tool</source>
        <translation>選擇圈型作為繪畫工具</translation>
    </message>
</context>
<context>
    <name>ColorPickerWidget</name>
    <message>
        <location filename="../src/widgets/panel/colorpickerwidget.cpp" line="64"/>
        <source>Active color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/panel/colorpickerwidget.cpp" line="164"/>
        <source>Press ESC to cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widgets/panel/colorpickerwidget.cpp" line="166"/>
        <source>Grab Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="../src/config/configwindow.cpp" line="41"/>
        <source>Configuration</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/config/configwindow.cpp" line="63"/>
        <source>Interface</source>
        <translation>介面</translation>
    </message>
    <message>
        <location filename="../src/config/configwindow.cpp" line="68"/>
        <source>Filename Editor</source>
        <translation>檔案名稱編輯器</translation>
    </message>
    <message>
        <location filename="../src/config/configwindow.cpp" line="73"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../src/core/controller.cpp" line="169"/>
        <source>&amp;Take Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/controller.cpp" line="174"/>
        <source>&amp;Configuration</source>
        <translation>&amp;設定</translation>
    </message>
    <message>
        <location filename="../src/core/controller.cpp" line="177"/>
        <source>&amp;Information</source>
        <translation>&amp;資訊</translation>
    </message>
    <message>
        <location filename="../src/core/controller.cpp" line="180"/>
        <source>&amp;Quit</source>
        <translation>&amp;結束</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <location filename="../src/tools/copy/copytool.cpp" line="35"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/tools/copy/copytool.cpp" line="43"/>
        <source>Copies the selection into the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <location filename="../src/utils/dbusutils.cpp" line="43"/>
        <source>Unable to connect via DBus</source>
        <translation>無法透過 DBus 進行連接</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <location filename="../src/tools/exit/exittool.cpp" line="34"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../src/tools/exit/exittool.cpp" line="42"/>
        <source>Leave the capture screen</source>
        <translation>離開螢幕擷取</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="35"/>
        <source>Edit the name of your captures:</source>
        <translation>編輯您的截圖名稱:</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="39"/>
        <source>Edit:</source>
        <translation>編輯器:</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="41"/>
        <source>Preview:</source>
        <translation>預覽:</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="78"/>
        <source>Save</source>
        <translation>存檔</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="80"/>
        <source>Saves the pattern</source>
        <translation>儲存樣式</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="82"/>
        <source>Reset</source>
        <translation>重設</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="85"/>
        <source>Restores the saved pattern</source>
        <translation>恢復儲存的樣式</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="87"/>
        <source>Clear</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../src/config/filenameeditor.cpp" line="91"/>
        <source>Deletes the name</source>
        <translation>刪除這個名稱</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="132"/>
        <source>Show help message</source>
        <translation>顯示説明資訊</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="136"/>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation>在擷取之前顯示説明資訊</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="146"/>
        <location filename="../src/config/geneneralconf.cpp" line="150"/>
        <source>Show desktop notifications</source>
        <translation>顯示桌面通知</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="159"/>
        <source>Show tray icon</source>
        <translation>顯示託盤圖示</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="163"/>
        <source>Show the systemtray icon</source>
        <translation>顯示工作列圖示</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="78"/>
        <location filename="../src/config/geneneralconf.cpp" line="184"/>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="85"/>
        <location filename="../src/config/geneneralconf.cpp" line="93"/>
        <location filename="../src/config/geneneralconf.cpp" line="115"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="85"/>
        <source>Unable to read file.</source>
        <translation>無法讀取檔案</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="93"/>
        <location filename="../src/config/geneneralconf.cpp" line="115"/>
        <source>Unable to write file.</source>
        <translation>無法寫入檔案</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="101"/>
        <source>Save File</source>
        <translation>存檔</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="122"/>
        <source>Confirm Reset</source>
        <translation>確認重設</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="123"/>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>你確定你想要重設？</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="174"/>
        <source>Configuration File</source>
        <translation>設定檔</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="179"/>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="189"/>
        <source>Reset</source>
        <translation>重設</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="197"/>
        <source>Launch at startup</source>
        <translation>自動啟動</translation>
    </message>
    <message>
        <location filename="../src/config/geneneralconf.cpp" line="201"/>
        <source>Launch Flameshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="47"/>
        <source>Upload to Imgur</source>
        <translation>上傳到 Imgur</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="53"/>
        <source>Uploading Image</source>
        <translation>正在上傳</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="133"/>
        <source>Copy URL</source>
        <translation>複製連結</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="134"/>
        <source>Open URL</source>
        <translation>打開連結</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="135"/>
        <source>Delete image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="136"/>
        <source>Image to Clipboard.</source>
        <translation>將檔案複製到剪貼簿</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="155"/>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="168"/>
        <source>Unable to open the URL.</source>
        <translation>無法打開此連結</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="161"/>
        <source>URL copied to clipboard.</source>
        <translation>連結已複製到剪貼簿</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploader.cpp" line="174"/>
        <source>Screenshot copied to clipboard.</source>
        <translation>截圖已複製到剪貼簿</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <location filename="../src/tools/imgur/imguruploadertool.cpp" line="35"/>
        <source>Image Uploader</source>
        <translation>上傳圖片</translation>
    </message>
    <message>
        <location filename="../src/tools/imgur/imguruploadertool.cpp" line="43"/>
        <source>Uploads the selection to Imgur</source>
        <translation>上傳到 Imgur</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="31"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="48"/>
        <source>Right Click</source>
        <translation>右鍵</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="49"/>
        <source>Mouse Wheel</source>
        <translation>滑鼠滑輪</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="53"/>
        <source>Move selection 1px</source>
        <translation>移動 1px</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="54"/>
        <source>Resize selection 1px</source>
        <translation>調整大小 1px</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="55"/>
        <source>Quit capture</source>
        <translation>結束擷取</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="56"/>
        <source>Copy to clipboard</source>
        <translation>複製到剪貼簿</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="57"/>
        <source>Save selection as a file</source>
        <translation>將選擇範圍另存新檔</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="58"/>
        <source>Undo the last modification</source>
        <translation>復原上次修改</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="59"/>
        <source>Show color picker</source>
        <translation>顯示顏色選擇器</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="60"/>
        <source>Change the tool&apos;s thickness</source>
        <translation>改變工具的寬度</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="76"/>
        <source>Key</source>
        <translation>鍵</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="76"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="107"/>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;授權條款&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="115"/>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;版本&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="125"/>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;快速鍵&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../src/widgets/infowindow.cpp" line="65"/>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>螢幕擷取模式中的可用快速鍵</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <location filename="../src/tools/line/linetool.cpp" line="42"/>
        <source>Line</source>
        <translation>直線</translation>
    </message>
    <message>
        <location filename="../src/tools/line/linetool.cpp" line="50"/>
        <source>Sets the Line as the paint tool</source>
        <translation>將直線線設定為繪畫工具</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <location filename="../src/tools/marker/markertool.cpp" line="42"/>
        <source>Marker</source>
        <translation>標記</translation>
    </message>
    <message>
        <location filename="../src/tools/marker/markertool.cpp" line="50"/>
        <source>Sets the Marker as the paint tool</source>
        <translation>將標記設定為繪畫工具</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <location filename="../src/tools/move/movetool.cpp" line="34"/>
        <source>Move</source>
        <translation>移動</translation>
    </message>
    <message>
        <location filename="../src/tools/move/movetool.cpp" line="42"/>
        <source>Move the selection area</source>
        <translation>移動選擇區域</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <location filename="../src/tools/pencil/penciltool.cpp" line="30"/>
        <source>Pencil</source>
        <translation>鉛筆</translation>
    </message>
    <message>
        <location filename="../src/tools/pencil/penciltool.cpp" line="38"/>
        <source>Sets the Pencil as the paint tool</source>
        <translation>將鉛筆設定為繪畫工具</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <location filename="../src/tools/pin/pintool.cpp" line="34"/>
        <source>Pin Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/pin/pintool.cpp" line="42"/>
        <source>Pin image on the desktop</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/utils/screenshotsaver.cpp" line="84"/>
        <source>Save Error</source>
        <translation>存檔錯誤</translation>
    </message>
    <message>
        <location filename="../src/utils/screenshotsaver.cpp" line="47"/>
        <location filename="../src/utils/screenshotsaver.cpp" line="78"/>
        <source>Capture saved as </source>
        <translation>截圖已另存為 </translation>
    </message>
    <message>
        <location filename="../src/utils/screenshotsaver.cpp" line="33"/>
        <source>Capture saved to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/utils/screenshotsaver.cpp" line="49"/>
        <location filename="../src/utils/screenshotsaver.cpp" line="81"/>
        <source>Error trying to save as </source>
        <translation>嘗試另存新檔時發生錯誤 </translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="72"/>
        <location filename="../src/main.cpp" line="359"/>
        <location filename="../src/main.cpp" line="383"/>
        <location filename="../src/main.cpp" line="412"/>
        <source>Unable to connect via DBus</source>
        <translation>無法透過 DBus 進行連接</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/openwithprogram.cpp" line="39"/>
        <source>Error</source>
        <translation type="unfinished">錯誤</translation>
    </message>
    <message>
        <location filename="../src/tools/launcher/openwithprogram.cpp" line="40"/>
        <source>Unable to write in</source>
        <translation type="unfinished">無法寫入</translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <location filename="../src/tools/rectangle/rectangletool.cpp" line="34"/>
        <source>Rectangle</source>
        <translation>實心矩形</translation>
    </message>
    <message>
        <location filename="../src/tools/rectangle/rectangletool.cpp" line="42"/>
        <source>Sets the Rectangle as the paint tool</source>
        <translation>將實心矩形設定為繪畫工具</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <location filename="../src/tools/redo/redotool.cpp" line="34"/>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/redo/redotool.cpp" line="42"/>
        <source>Redo the next modification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <location filename="../src/tools/save/savetool.cpp" line="35"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../src/tools/save/savetool.cpp" line="43"/>
        <source>Save the capture</source>
        <translation>儲存擷取</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <location filename="../src/utils/screengrabber.cpp" line="70"/>
        <source>Unable to capture screen</source>
        <translation type="unfinished">無法擷取螢幕</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../src/tools/selection/selectiontool.cpp" line="38"/>
        <source>Rectangular Selection</source>
        <translation>矩形選擇</translation>
    </message>
    <message>
        <location filename="../src/tools/selection/selectiontool.cpp" line="46"/>
        <source>Sets the Selection as the paint tool</source>
        <translation>將矩形選擇設定為繪畫工具</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <location filename="../src/tools/sizeindicator/sizeindicatortool.cpp" line="34"/>
        <source>Selection Size Indicator</source>
        <translation>選擇尺寸指示</translation>
    </message>
    <message>
        <location filename="../src/tools/sizeindicator/sizeindicatortool.cpp" line="42"/>
        <source>Shows the dimensions of the selection (X Y)</source>
        <translation>顯示選擇的尺寸 (X Y)</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="47"/>
        <source>Century (00-99)</source>
        <translation>世紀 (00-99)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="48"/>
        <source>Year (00-99)</source>
        <translation>年 (00-99)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="49"/>
        <source>Year (2000)</source>
        <translation>年 (2000)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="50"/>
        <source>Month Name (jan)</source>
        <translation>月 (jul)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="51"/>
        <source>Month Name (january)</source>
        <translation>月 (juliol)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="52"/>
        <source>Month (01-12)</source>
        <translation>月 (01-12)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="53"/>
        <source>Week Day (1-7)</source>
        <translation>平常日 (1-7)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="54"/>
        <source>Week (01-53)</source>
        <translation>周 (01-53)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="55"/>
        <source>Day Name (mon)</source>
        <translation>星期 (dg)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="56"/>
        <source>Day Name (monday)</source>
        <translation>星期 (diumenge)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="57"/>
        <source>Day (01-31)</source>
        <translation>天 (01-31)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="58"/>
        <source>Day of Month (1-31)</source>
        <translation>一月中的某天 (1-31)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="59"/>
        <source>Day (001-366)</source>
        <translation>天 (001-366)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="60"/>
        <source>Time (%H-%M-%S)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="61"/>
        <source>Time (%H-%M)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="62"/>
        <source>Hour (00-23)</source>
        <translation>小時 (00-23)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="63"/>
        <source>Hour (01-12)</source>
        <translation>小時 (01-12)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="64"/>
        <source>Minute (00-59)</source>
        <translation>分鐘 (00-59)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="65"/>
        <source>Second (00-59)</source>
        <translation>秒 (00-59)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="66"/>
        <source>Full Date (%m/%d/%y)</source>
        <translation>日期 (%m/%d/%y)</translation>
    </message>
    <message>
        <location filename="../src/config/strftimechooserwidget.cpp" line="67"/>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>日期 (%Y-%m-%d)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <location filename="../src/utils/systemnotification.cpp" line="28"/>
        <source>Flameshot Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <location filename="../src/tools/text/textconfig.cpp" line="49"/>
        <source>StrikeOut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/text/textconfig.cpp" line="56"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/text/textconfig.cpp" line="63"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/text/textconfig.cpp" line="70"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <location filename="../src/tools/text/texttool.cpp" line="50"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tools/text/texttool.cpp" line="58"/>
        <source>Add text to your capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="30"/>
        <source>UI Color Editor</source>
        <translation>UI 顏色編輯器</translation>
    </message>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="93"/>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>移動顏色選擇並在預覽按鈕檢視</translation>
    </message>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="103"/>
        <source>Select a Button to modify it</source>
        <translation>選擇一個按鈕來修改它</translation>
    </message>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="112"/>
        <source>Main Color</source>
        <translation>主色</translation>
    </message>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="116"/>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation>點選按鈕設定主色</translation>
    </message>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="127"/>
        <source>Contrast Color</source>
        <translation>對比色</translation>
    </message>
    <message>
        <location filename="../src/config/uicoloreditor.cpp" line="132"/>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation>點選按鈕設定對比色</translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <location filename="../src/tools/undo/undotool.cpp" line="34"/>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../src/tools/undo/undotool.cpp" line="42"/>
        <source>Undo the last modification</source>
        <translation>復原上次修改</translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <location filename="../src/config/visualseditor.cpp" line="53"/>
        <source>Opacity of area outside selection:</source>
        <translation>選擇區域以外的不透明度</translation>
    </message>
    <message>
        <location filename="../src/config/visualseditor.cpp" line="77"/>
        <source>Button Selection</source>
        <translation>按鈕選擇</translation>
    </message>
    <message>
        <location filename="../src/config/visualseditor.cpp" line="83"/>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
</context>
</TS>
